import { TransactionBaseService } from '@medusajs/medusa';
import { type Redis } from 'ioredis';
import { type PluginOptions } from '../types/options';
/**
 * Dependencies injected into the RateLimitService.
 */
type InjectedDependencies = {
    redisClient: Redis;
};
/**
 * Service for managing rate limiting functionality.
 * @extends TransactionBaseService
 */
declare class RateLimitService extends TransactionBaseService {
    /** The Redis client used for rate limiting operations. */
    protected readonly redisClient_: Redis;
    /**
     * Default options for rate limiting.
     * @default { limit: 5, window: 60 } - 5 requests per minute (60 seconds window) before blocking
     *
     */
    private readonly options_;
    /**
     * Creates an instance of RateLimitService.
     * @param {InjectedDependencies} container - The injected dependencies.
     * @param {PluginOptions} options - The options for rate limiting.
     */
    constructor(container: InjectedDependencies, options: PluginOptions);
    /**
     * Limits the number of attempts for the given key.
     * @param {string} key - The key to limit.
     * @returns {Promise<boolean>} True if the limit is not exceeded, false otherwise.
     */
    limit(key: string): Promise<boolean>;
    /**
     * Returns the number of remaining attempts for the given key.
     * @param {string} key - The key to check.
     * @returns {Promise<number>} The number of remaining attempts.
     */
    getRemainingAttempts(key: string): Promise<number>;
    /**
     * Resets the limit for the given key.
     * @param {string} key - The key to reset.
     * @returns {Promise<void>}
     */
    resetLimit(key: string): Promise<void>;
    /**
     * Returns the time to live of the given key in seconds.
     * @param {string} key - The key to check.
     * @returns {Promise<number>} The time to live in seconds.
     */
    ttl(key: string): Promise<number>;
    getOptions(): PluginOptions;
}
export default RateLimitService;
